@@ -23,16 +23,20 @@ require 5.004;
 use strict;
 use Carp;
 use vars qw'$VERSION';
-$VERSION = 0.74;
+$VERSION = 0.88;
 
 use Text::BibTeX;
 
+=encoding UTF-8
+
 =head1 NAME
 
 Text::BibTeX::Name - interface to BibTeX-style author names
 
 =head1 SYNOPSIS
 
+   use Text::BibTeX::Name;
+
    $name = Text::BibTeX::Name->new();
    $name->split('J. Random Hacker');
    # or:
@@ -269,7 +273,7 @@ way is the job of another module: see L<Text::BibTeX::NameFormat>.
 
 =over 4
 
-=item new([ NAME [, FILENAME, LINE, NAME_NUM]])
+=item new([ [OPTS,] NAME [, FILENAME, LINE, NAME_NUM]])
 
 Creates a new C<Text::BibTeX::Name> object.  If NAME is supplied, it
 must be a string containing a single name, and it will be be passed to
@@ -277,17 +281,46 @@ the C<split> method for further processing.  FILENAME, LINE, and
 NAME_NUM, if present, are all also passed to C<split> to allow better
 error messages.
 
+If the first argument is a hash reference, it is used to define
+configuration values. At the moment the available values are:
+
+=over 4 
+
+=item BINMODE
+
+Set the way Text::BibTeX deals with strings. By default it manages
+strings as bytes. You can set BINMODE to 'utf-8' to get NFC normalized
+UTF-8 strings and you can customise the normalization with the NORMALIZATION option.
+
+   Text::BibTeX::Name->new(
+      { binmode => 'utf-8', normalization => 'NFD' },
+      "Alberto Simões"});
+
+=back
+
 =cut
 
-sub new
-{
-   my ($class, $name, $filename, $line, $name_num) = @_;
+sub new {
+    my $class = shift;
+    my $opts = ref $_[0] eq 'HASH' ? shift : {};
 
-   $class = ref ($class) || $class;
-   my $self = bless {}, $class;
-   $self->split ($name, $filename, $line, $name_num, 1)
-      if (defined $name);
-   $self;
+    $opts->{ lc $_ } = $opts->{$_} for ( keys %$opts );
+
+    my ( $name, $filename, $line, $name_num ) = @_;
+
+    $class = ref($class) || $class;
+    my $self = bless { }, $class;
+
+    $self->{binmode} = 'bytes';
+    $self->{normalization} = 'NFC';
+    $self->{binmode} = 'utf-8'
+        if exists $opts->{binmode} && $opts->{binmode} =~ /utf-?8/i;
+    $self->{normalization} = $opts->{normalization} if exists $opts->{normalization};
+
+    $self->split( Text::BibTeX->_process_argument($name, $self->{binmode}, $self->{normalization}),
+        $filename, $line, $name_num, 1 )
+        if ( defined $name );
+    $self;
 }
 
 
@@ -317,7 +350,7 @@ sub split
    my ($self, $name, $filename, $line, $name_num) = @_;
 
    # Call the XSUB with default values if necessary
-   $self->_split ($name, $filename, 
+   $self->_split (Text::BibTeX->_process_argument($name, $self->{binmode}, $self->{normalization}), $filename, 
                   defined $line ? $line : -1,
                   defined $name_num ? $name_num : -1,
                   1);
@@ -341,13 +374,18 @@ would return the list C<('de','la')>.
 
 =cut
 
-sub part
-{
-   my ($self, $partname) = @_;
+sub part {
+    my ( $self, $partname ) = @_;
 
-   croak "unknown name part" 
-      unless $partname =~ /^(first|von|last|jr)$/;
-   exists $self->{$partname} ? @{$self->{$partname}} : ();
+    croak "unknown name part"
+        unless $partname =~ /^(first|von|last|jr)$/;
+
+    if ( exists $self->{$partname} ) {
+        my @x = map { Text::BibTeX->_process_result($_, $self->{binmode}, $self->{normalization}) }
+            @{ $self->{$partname} };
+        return @x > 1 ? @x : $x[0];
+    }
+    return undef;
 }
 
 
